bayespy.inference.vmp.nodes.categorical.CategoricalMoments
==========================================================

.. currentmodule:: bayespy.inference.vmp.nodes.categorical

.. autoclass:: CategoricalMoments

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
      :toctree: generated/
   
      ~CategoricalMoments.__init__
      ~CategoricalMoments.add_converter
      ~CategoricalMoments.compute_dims_from_values
      ~CategoricalMoments.compute_fixed_moments
      ~CategoricalMoments.get_converter
   
   

   
   
   